@@ -17,16 +17,15 @@ def cell_parser_hisat_summary(stat_path):
     """
     cell_id = pathlib.Path(stat_path).name.split('.')[0]
     term_dict = {
-        'Total pairs': f'ReadPairsMappedInPE',
-        'Aligned concordantly or discordantly 0 time':
-            f'PEUnmappableReadPairs',
-        'Aligned concordantly 1 time': f'PEUniqueMappedReadPairs',
-        'Aligned concordantly >1 times': f'PEMultiMappedReadPairs',
-        'Aligned discordantly 1 time': f'PEDiscordantlyUniqueMappedReadPairs',
-        'Total unpaired reads': f'ReadsMappedInSE',
-        'Aligned 0 time': f'SEUnmappableReads',
-        'Aligned 1 time': f'SEUniqueMappedReads',
-        'Aligned >1 times': f'SEMultiMappedReads',
+        'Total pairs': 'ReadPairsMappedInPE',
+        'Aligned concordantly or discordantly 0 time': 'PEUnmappableReadPairs',
+        'Aligned concordantly 1 time': 'PEUniqueMappedReadPairs',
+        'Aligned concordantly >1 times': 'PEMultiMappedReadPairs',
+        'Aligned discordantly 1 time': 'PEDiscordantlyUniqueMappedReadPairs',
+        'Total unpaired reads': 'ReadsMappedInSE',
+        'Aligned 0 time': 'SEUnmappableReads',
+        'Aligned 1 time': 'SEUniqueMappedReads',
+        'Aligned >1 times': 'SEMultiMappedReads',
     }
 
     with open(stat_path) as rep:
@@ -42,9 +41,9 @@ def cell_parser_hisat_summary(stat_path):
                     ' ')[0].strip('%')
             except KeyError:
                 pass
-        for k in term_dict.keys():
-            if k not in report_dict:
-                report_dict[term_dict[k]] = 0
+        for v in term_dict.values():
+            if v not in report_dict:
+                report_dict[v] = 0
 
         report_dict = pd.Series(report_dict).astype(int)
         total_reads = report_dict[f'ReadPairsMappedInPE'] * 2 + report_dict[
@@ -184,18 +183,33 @@ def cell_parser_reads_mc_frac_profile(path):
             else:
                 break
 
+    params['cov_min_threshold'] = int(params['cov_min_threshold'])
+    # the mc_frac col in stats file is in %
+    try:
+        params['mc_rate_max_threshold'] = float(params['mc_rate_max_threshold'])
+        if params['mc_rate_max_threshold'] <= 1:
+            params['mc_rate_max_threshold'] *= 100
+    except ValueError:
+        pass
+    try:
+        params['mc_rate_min_threshold'] = float(params['mc_rate_min_threshold'])
+        if params['mc_rate_min_threshold'] <= 1:
+            params['mc_rate_min_threshold'] *= 100
+    except ValueError:
+        pass
+
     path = pathlib.Path(path)
     cell_id = path.name.split('.')[0]
     reads_profile = pd.read_csv(path, comment='#')
     mode = params['mode'].upper()
     if mode == 'DNA':
         selected_reads = reads_profile[
-            (reads_profile['cov'] >= int(params['cov_min_threshold']))
-            & (reads_profile['mc_frac'] < float(params['mc_rate_max_threshold']))]
+            (reads_profile['cov'] >= params['cov_min_threshold'])
+            & (reads_profile['mc_frac'] < params['mc_rate_max_threshold'])]
     else:
         selected_reads = reads_profile[
-            (reads_profile['cov'] >= int(params['cov_min_threshold']))
-            & (reads_profile['mc_frac'] > float(params['mc_rate_min_threshold']))]
+            (reads_profile['cov'] >= params['cov_min_threshold'])
+            & (reads_profile['mc_frac'] > params['mc_rate_min_threshold'])]
 
     selected_reads = selected_reads['count'].sum()
     selected_ratio = selected_reads / (reads_profile['count'].sum() + 0.0001)
@@ -205,6 +219,17 @@ def cell_parser_reads_mc_frac_profile(path):
     return final_stat
 
 
+def cell_parser_feature_count_summary(path):
+    result = pd.read_csv(path, sep='\t', index_col=0).squeeze()
+    all_reads = result.sum()
+
+    result.index.name = None
+    result.name = result.name.split(':')[-1]  # cell id
+    result['Unassigned_Total'] = result[result.index.str.startswith('Unassigned')].sum()
+    result['AssignedRNAReadsRate'] = int(result['Assigned'] / (all_reads + 0.00001) * 100)
+    return result
+
+
 def parse_single_stats_set(path_pattern, parser, prefix=''):
     """
     Parse all the stats files in the path_pattern and return a dataframe
@@ -271,5 +296,5 @@ def parse_single_stats_set(path_pattern, parser, prefix=''):
     stats_df = stats_df.iloc[:, new_columns != 'DELETE'].copy()
 
     # add prefix to stats_df columns
-    stats_df.columns = stats_df.columns.map(lambda a: prefix + a)
+    stats_df.columns = stats_df.columns.map(lambda a: prefix + str(a))
     return stats_df
