@@ -24,11 +24,15 @@ def mc_config_str(config):
         'r1_adapter': 'AGATCGGAAGAGCACACGTCTGAAC',
         'r2_adapter': 'AGATCGGAAGAGCGTCGTGTAGGGA',
         'bismark_reference': 'required',
+        'hisat3n_dna_reference': 'required',
+        'hisat3n_repeat_index_type': 'no-repeat',
         'reference_fasta': 'required',
-        'chrom_sizes_file': 'required',
+        'chrom_size_path': 'required',
         'mc_stat_feature': 'CHN CGN CCC',
         'mc_stat_alias': 'mCH mCG mCCC'
     }
+    if 'hisat3n_dna_reference' in config:
+        del str_parameters['bismark_reference']
 
     typed_config = {}
     for k, default in int_parameters.items():
